@@ -22,7 +22,7 @@ yn(defined(&hello_world));
 
 
 package sisponyS::Desc2;
-our @ISA = ('Synopsis');
+BEGIN {our @ISA = ('Synopsis')}; # to be correct
 use Package::Autoloader sub{eval shift};
 
 my $obj = bless( \(my $o = 0), 'sisponyS::Desc2');
@@ -47,4 +47,4 @@ use Package::Autoloader sub{eval shift}, sub {
 	$_[0]->register_rule($yn, '*', 'yn');
 };
 
-exit(0);
\ No newline at end of file
+exit(0);
