@@ -2,7 +2,21 @@ package Package::Autoloader::Generator;
 use strict;
 use warnings;
 
-sub ATB_GENERATOR() { 0 };
+sub new {
+	my ($class) = (shift);
+
+	my $self = [@_];
+	bless($self, $class);
+	$self->_init(@_) if ($self->can('_init'));
+	Internals::SvREADONLY(@{$self}, 1);
+
+	return($self);
+}
+
+sub implement {
+	my $self = shift;
+	return($self->[0]->(@_));
+}
 
 my $std_sub = q{
 	sub %s { %s };
@@ -11,21 +25,42 @@ my $std_sub = q{
 sub run {
 	my ($self, $pkg, $pkg_name, $sub_name) = (shift, shift, shift, shift);
 
-	my $code = $self->[ATB_GENERATOR]->($pkg, $sub_name, @_);
+	my $code = $self->implement($pkg, $sub_name, @_);
 	return unless (defined($code));
 	if (ref($code) eq '') {
 		unless ($code =~ m,^[\n\t\s]*sub[\n\t\s],) {
 			$code = sprintf($std_sub, $sub_name, $code, $sub_name);
 		}
-
 		$code = $pkg->transport(\$code);
 	}
 
 	unless (defined($code)) {
-		Carp::confess("Unable to create '$sub_name' for $pkg_name (generator failed).");
+		return(failure(ref($self), $sub_name, ' [generator failed]'));
 	}
 	return($code);
-};
+}
+
+my %CLASSES = ();
+sub new_class {
+	my ($name, $pkg) = @_;
+
+	unless(exists($CLASSES{$name})) {
+		my $class;
+		if (substr($name, 0, 2) eq '::') {
+			$class = "Package::Autoloader::Generator$name";
+		} else {
+			$class = $name;
+		}
+		# shows the impractical parts of Perl5
+		my $class_for_require = $class;
+		$class_for_require =~ s,::,/,sg;
+		$class_for_require .= '.pm';
+		#local $!; # isn't this handled inside require?
+		require $class_for_require;
+		$CLASSES{$name} = $class;
+	}
+	return($CLASSES{$name}->new($pkg));
+}
 
 sub failure {
 	my ($pkg_name, $sub_name, $what) = @_;
@@ -48,4 +83,4 @@ sub failure {
 	return($failure);
 }
 
-1;
\ No newline at end of file
+1;
