@@ -7,13 +7,13 @@ use parent qw(
 # allow AUTOLOAD to eventually trigger AUTOLOAD?
 our $ONLY_DEFINED_ORIGINALS = 1;
 
-sub new {
-	my ($class, $defining_pkg) = (shift, shift);
+sub ATB_PKG() { 0 };
 
-	my $generator = sub {
-		my ($pkg, $sub_name) = (shift, shift);
+sub implement {
+	my ($self, $pkg, $sub_name) = (shift, shift, shift);
 
-		my $sub_text = sprintf(q{
+	my $defining_pkg = $self->[ATB_PKG];
+	my $sub_text = sprintf(q{
 my ($only_defined_originals) = (shift(@_));
 if ($only_defined_originals and !defined(&%s::%s)) {
 	return(Package::Autoloader::Generator::failure('%s', '%s', '::Export [original does not exist]'));
@@ -22,18 +22,12 @@ my $sub_ref = \&%s::%s;
 *%s = $sub_ref;
 return($sub_ref);
 		}, 
-			$defining_pkg->name, $sub_name,
-			$defining_pkg->name, $sub_name,
-			$defining_pkg->name, $sub_name,
-			$sub_name);
+		$defining_pkg->name, $sub_name,
+		$defining_pkg->name, $sub_name,
+		$defining_pkg->name, $sub_name,
+		$sub_name);
 
- 		return($pkg->transport(\$sub_text, $ONLY_DEFINED_ORIGINALS));
-	};
-	my $self = [$generator];
-	bless($self, $class);
-	Internals::SvREADONLY(@{$self}, 1);
-
-	return($self);
+	return($pkg->transport(\$sub_text, $ONLY_DEFINED_ORIGINALS));
 }
 
-1;
\ No newline at end of file
+1;
